---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: true
description: "Translate the Open Web Calender"
---

# Translate

You can help us by [translating the project]({{link.weblate}}) to your language.
If your language is not listed, please request to add it!

- [Translate on Weblate]({{link.weblate}})

Here, you can see the current translation status:

[![Translation status](https://hosted.weblate.org/widgets/open-web-calendar/-/multi-auto.svg)]({{link.weblate}})

## Translator Guide

Translations are contributed by volunteers and [logged](../../changelog).
After 48 hours they are usually life at the [hosted instance]({{link.web}}).

1. The most important file is probably the **calendar file**.
2. The **About Page** and **Common Translations** is also very important as users see it when they click the `?` at the bottom right.
3. If you would like to have the **Configuration Page** available for people in your language.
4. You are very welcome to also translate the documentation:

    1. The **Documentation - Getting Started** motivates usage.
    2. The **Documentation - Examples** showcase how to use the calendar.

Generally, feel free to translate the title and translate the sense of the content more than the literal words.
I am not a native speaker, so my English is a bit clunky and your translation could be better!

**Note:**

- If you add a **new language**, you should also translate the calendar to it, especially the `language` and `language-en` strings so people can choose the language for the calendar from the drop down menu.
- If you want your language to be featured at the top of the front page so people can click on it, you need at least 50% of the About Page and Configuration Page page.

Have **fun** translating and thank you so much! If you have any questions, get in contact with me, @niccokunzmann.

Feel free to add a section for your language below:

### German (de)

We use "Du" and "Dein", not "Sie" or "Ihr".
